@@ -865,7 +865,7 @@ class log_monitor_manager {
     }
     
     private function remove_ftp_service_block($ip) {
-        $ftp_blocked_file = '/etc/proftpd/whp_blocked_ips.conf';
+        $ftp_blocked_file = '/etc/proftpd/conf.d/whp_blocked_ips.conf';
         
         if (!file_exists($ftp_blocked_file)) {
             return true; // Nothing to remove
@@ -883,9 +883,10 @@ class log_monitor_manager {
                 return $blocked_ip !== $ip;
             });
             
-            // Write updated configuration
+            // Write updated configuration - use Global context to avoid Directory conflicts
             $config_content = "# WHP FTP Blocked IPs - Auto-generated\n";
-            $config_content .= "<Directory \"~\">\n";
+            $config_content .= "# Global FTP access restrictions\n";
+            $config_content .= "<Global>\n";
             $config_content .= "  <Limit LOGIN>\n";
             $config_content .= "    Order allow,deny\n";
             $config_content .= "    Allow from all\n";
@@ -893,7 +894,7 @@ class log_monitor_manager {
                 $config_content .= "    Deny from $blocked_ip\n";
             }
             $config_content .= "  </Limit>\n";
-            $config_content .= "</Directory>\n";
+            $config_content .= "</Global>\n";
             
             if (file_put_contents($ftp_blocked_file, $config_content, LOCK_EX) === false) {
                 return false;
@@ -1002,7 +1003,7 @@ class log_monitor_manager {
     }
     
     private function add_ftp_service_block($ip) {
-        $ftp_blocked_file = '/etc/proftpd/whp_blocked_ips.conf';
+        $ftp_blocked_file = '/etc/proftpd/conf.d/whp_blocked_ips.conf';
         
         // Read existing blocked IPs
         $blocked_ips = array();
@@ -1018,9 +1019,10 @@ class log_monitor_manager {
         if (!in_array($ip, $blocked_ips)) {
             $blocked_ips[] = $ip;
             
-            // Write updated configuration
+            // Write updated configuration - use Global context to avoid Directory conflicts
             $config_content = "# WHP FTP Blocked IPs - Auto-generated\n";
-            $config_content .= "<Directory \"~\">\n";
+            $config_content .= "# Global FTP access restrictions\n";
+            $config_content .= "<Global>\n";
             $config_content .= "  <Limit LOGIN>\n";
             $config_content .= "    Order allow,deny\n";
             $config_content .= "    Allow from all\n";
@@ -1028,7 +1030,7 @@ class log_monitor_manager {
                 $config_content .= "    Deny from $blocked_ip\n";
             }
             $config_content .= "  </Limit>\n";
-            $config_content .= "</Directory>\n";
+            $config_content .= "</Global>\n";
             
             if (file_put_contents($ftp_blocked_file, $config_content, LOCK_EX) === false) {
                 return false;
@@ -1070,12 +1072,23 @@ class log_monitor_manager {
     }
     
     private function ensure_ftp_config_include() {
+        // Files in /etc/proftpd/conf.d/ are automatically included by most ProFTPD installations
+        // So we don't need to manually add include statements
+        // Just ensure the conf.d directory exists
+        $conf_dir = '/etc/proftpd/conf.d';
+        if (!is_dir($conf_dir)) {
+            @mkdir($conf_dir, 0755, true);
+        }
+        
+        // For compatibility, still check if manual include is needed
         $main_config = '/etc/proftpd/proftpd.conf';
-        $include_line = 'Include /etc/proftpd/whp_blocked_ips.conf';
+        $include_line = 'Include /etc/proftpd/conf.d/whp_blocked_ips.conf';
         
         if (file_exists($main_config)) {
             $content = file_get_contents($main_config);
-            if (strpos($content, $include_line) === false) {
+            // Only add include if conf.d directory include is not already present
+            if (strpos($content, 'Include /etc/proftpd/conf.d') === false && 
+                strpos($content, $include_line) === false) {
                 // Add include at the end of the file
                 file_put_contents($main_config, "\n# WHP Blocked IPs Include\n$include_line\n", FILE_APPEND | LOCK_EX);
             }
